const { createDefaultConfig } = require('@open-wc/testing-karma');
const merge = require('deepmerge');

module.exports = config => {
	//	merging our stuff into default config
	const defaultConfig = createDefaultConfig(config);
	const extendedDefaultConfig = merge(defaultConfig, {
		files: [
			{ pattern: config.grep ? config.grep : 'packages/**/test/**/*.test.js', type: 'module' },
			{ pattern: 'packages/design-tokens/build/**/*.scss', included: false }
		],
		preprocessors: {
			'packages/design-tokens/build/scss/schemes/**/*.scss': ['file-fixtures'],
		},
		esm: {
			nodeResolve: true,
		},
		frameworks: ['chai'],
		reporters: ['karmaHTML'],
		browserDisconnectTimeout: 300000,
		browserNoActivityTimeout: 360000,
		singleRun: true,
		autoWatch: false,
		restartOnFileChange: true,
		captureTimeout: 420000,
		client: {
			karmaHTML: {
				source: [
					{ tag: 'contextSetupTest', src: 'packages/context/test/context-setup.test.html' },
					{ tag: 'coreSetupTest', src: 'packages/core/test/core-setup.test.html' },
					{ tag: 'fontsSetupTest', src: 'packages/fonts/test/fonts-setup.test.html' },
					{ tag: 'schemeSetupTest', src: 'packages/scheme/test/scheme-setup.test.html' },
					{ tag: 'drawerSetupTest', src: 'packages/drawer/test/drawer-setup.test.html' },
				]
			}
		},
		coverageReporter: {
			dir: `coverage/`,
			reporters: [
				{
					type: 'cobertura', subdir: 'report-cobertura', file: 'coverage.xml'
				},
				{
					type: 'lcovonly', subdir: 'report-lcov', file: 'lcov.info'
				}
			]
		}
	});

	config.set(extendedDefaultConfig);
	return config;
};
